% Sparse Kernel Mean (SKM) demo file
% See Efr\'en Cruz Cort\'es ans Clay Scott "Sparse Approximation of a
% Kernel Mean"
%
% Obtain data points from demo_data and approximate the Full Kernel Mean (FKM).
% Use full data to obtain FKM. Use skm() to obtain subset of
% data and optimal coefficients to build sparse approx. of FKM.
%
% Efr\'en Cruz Cort\'es, 2015
%

% Get some data
load demo_data;
X = g;

% Required parameters
k = 15;
sigma = 1.5;
% Some optional parameters
Hset = 'rkhs';
simplex = 0; % project into simplex after finding alpha
alpha_method = 1; % use update method described in paper
autoselection = 1; % use autoselection scheme

% Sparsify and find alphas
[I,alpha] = skm(X,k,sigma,'H',Hset,'smplx',simplex,'amthd',alpha_method,'auto',autoselection);

% plot
t = 50:0.1:100;
y=zeros(size(t));
figure
hold on
% This is the FKM:
for i = 1:length(t)
    y(i) = mean(normpdf(X,t(i),sigma));
end
h1 = plot(t,y,'b--','LineWidth',7);
Y = zeros(1,length(t));
% This is SKM
for j = 1:length(alpha)
    for i=1:length(t)
        y(i) = alpha(j)*normpdf(X(I(j)),t(i),sigma);
    end
    plot(t,y,'k')
    Y = Y+y;
end
h2 = plot(t,Y,'r','LineWidth',3);
set(gca,'TickLength',[.02,.02],...
        'TickDir','out',...
        'Box','off',...
        'LineWidth',2,...
        'FontSize',25)
legend([h1 h2], 'FKM','SKM')
title(['FKM vs SKM for k=' num2str(k)])
    